"""
Manimera Animations Package.

This package provides custom Animation classes for creating complex
visual effects and transitions.
"""

from .advance_clock_time import AdvanceClockTime

__all__ = ["AdvanceClockTime"]



"""
Manimera Components Package.

This package contains high-level, reusable Manim objects (Mobjects)
that are built from simpler primitives.
"""

from .clock import Clock
from .network_tower import NetworkTower
from .anatomical_eye import AnatomicalEye

__all__ = [
    "Clock",
    "NetworkTower",
    "AnatomicalEye",
]
